==> huaweicloudsdkiotda-3.0.5b0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/simple_timer_type.py <==
# coding: utf-8

import pprint
import re

import six


class SimpleTimerType(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'start_time': 'str',
        'repeat_interval': 'int',
        'repeat_count': 'int'
    }

    attribute_map = {
        'start_time': 'start_time',
        'repeat_interval': 'repeat_interval',
        'repeat_count': 'repeat_count'
    }

    def __init__(self, start_time=None, repeat_interval=None, repeat_count=None):  # noqa: E501
        """SimpleTimerType - a model defined in huaweicloud sdk"""

        self._start_time = None
        self._repeat_interval = None
        self._repeat_count = None
        self.discriminator = None

        self.start_time = start_time
        self.repeat_interval = repeat_interval
        self.repeat_count = repeat_count

    @property
    def start_time(self):
        """Gets the start_time of this SimpleTimerType.

        规则触发的开始时间，使用UTC时区，格式：yyyyMMdd'T'HHmmss'Z'。

        :return: The start_time of this SimpleTimerType.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SimpleTimerType.

        规则触发的开始时间，使用UTC时区，格式：yyyyMMdd'T'HHmmss'Z'。

        :param start_time: The start_time of this SimpleTimerType.
        :type: str
        """
        self._start_time = start_time

    @property
    def repeat_interval(self):
        """Gets the repeat_interval of this SimpleTimerType.

        规则触发的重复时间间隔，单位为秒。

        :return: The repeat_interval of this SimpleTimerType.
        :rtype: int
        """
        return self._repeat_interval

    @repeat_interval.setter
    def repeat_interval(self, repeat_interval):
        """Sets the repeat_interval of this SimpleTimerType.

        规则触发的重复时间间隔，单位为秒。

        :param repeat_interval: The repeat_interval of this SimpleTimerType.
        :type: int
        """
        self._repeat_interval = repeat_interval

    @property
    def repeat_count(self):
        """Gets the repeat_count of this SimpleTimerType.

        规则触发的重复次数。

        :return: The repeat_count of this SimpleTimerType.
        :rtype: int
        """
        return self._repeat_count

    @repeat_count.setter
    def repeat_count(self, repeat_count):
        """Sets the repeat_count of this SimpleTimerType.

        规则触发的重复次数。

        :param repeat_count: The repeat_count of this SimpleTimerType.
        :type: int
        """
        self._repeat_count = repeat_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleTimerType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.0.17b0-py3-none-any.whl: huaweicloudsdkiotda/v5/model/simple_timer_type.py <==
# coding: utf-8

import pprint
import re

import six





class SimpleTimerType:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'start_time': 'str',
        'repeat_interval': 'int',
        'repeat_count': 'int'
    }

    attribute_map = {
        'start_time': 'start_time',
        'repeat_interval': 'repeat_interval',
        'repeat_count': 'repeat_count'
    }

    def __init__(self, start_time=None, repeat_interval=None, repeat_count=None):
        """SimpleTimerType - a model defined in huaweicloud sdk"""
        
        

        self._start_time = None
        self._repeat_interval = None
        self._repeat_count = None
        self.discriminator = None

        self.start_time = start_time
        self.repeat_interval = repeat_interval
        self.repeat_count = repeat_count

    @property
    def start_time(self):
        """Gets the start_time of this SimpleTimerType.

        规则触发的开始时间，使用UTC时区，格式：yyyyMMdd'T'HHmmss'Z'。

        :return: The start_time of this SimpleTimerType.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SimpleTimerType.

        规则触发的开始时间，使用UTC时区，格式：yyyyMMdd'T'HHmmss'Z'。

        :param start_time: The start_time of this SimpleTimerType.
        :type: str
        """
        self._start_time = start_time

    @property
    def repeat_interval(self):
        """Gets the repeat_interval of this SimpleTimerType.

        规则触发的重复时间间隔，单位为秒。

        :return: The repeat_interval of this SimpleTimerType.
        :rtype: int
        """
        return self._repeat_interval

    @repeat_interval.setter
    def repeat_interval(self, repeat_interval):
        """Sets the repeat_interval of this SimpleTimerType.

        规则触发的重复时间间隔，单位为秒。

        :param repeat_interval: The repeat_interval of this SimpleTimerType.
        :type: int
        """
        self._repeat_interval = repeat_interval

    @property
    def repeat_count(self):
        """Gets the repeat_count of this SimpleTimerType.

        规则触发的重复次数。

        :return: The repeat_count of this SimpleTimerType.
        :rtype: int
        """
        return self._repeat_count

    @repeat_count.setter
    def repeat_count(self, repeat_count):
        """Sets the repeat_count of this SimpleTimerType.

        规则触发的重复次数。

        :param repeat_count: The repeat_count of this SimpleTimerType.
        :type: int
        """
        self._repeat_count = repeat_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleTimerType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
